#
# spec file for package vulkan-headers
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# vkinfo reports vulkan-headers's version even if the loader/tools/etc.
# are at an older version, which in the past confused some users.
# Consider only updating the sources in lockstep.
#

Name:           vulkan-headers
Version:        1.3.275.0
Release:        1.2
Summary:        Vulkan C and C++ API header files
License:        Apache-2.0
Group:          Development/Libraries/C and C++
URL:            https://github.com/KhronosGroup/Vulkan-Headers
Source:         https://github.com/KhronosGroup/Vulkan-Headers/archive/refs/tags/vulkan-sdk-%version.tar.gz
Source9:        %name-rpmlintrc
BuildRequires:  cmake >= 2.8.11
BuildArch:      noarch
Requires:       pkgconfig(wayland-client)
Requires:       pkgconfig(x11)
Requires:       pkgconfig(xcb)
Requires:       pkgconfig(xrandr)
Conflicts:      vulkan-devel < 1.1.91

%description
Vulkan is a 3D graphics and compute API providing cross-platform
access to modern GPUs with low overhead and targeting realtime
graphics applications such as games and interactive media.

This package contains the development headers for packages wanting
to make use of Vulkan.

%prep
%autosetup -n Vulkan-Headers-vulkan-sdk-%version -p1

%build
%cmake \
	-DCMAKE_INSTALL_SYSCONFDIR="%_sysconfdir" \
	-DBUILD_WSI_MIR_SUPPORT=OFF \
	-DBUILD_TESTS=OFF
%cmake_build

%install
%cmake_install

%files
%license LICENSE.md
%_includedir/vulkan/
%_includedir/vk_video/
%_datadir/cmake/
%_datadir/vulkan/

%changelog
* Thu Jan 18 2024 Nicolas FORMICHELLA <stigpro@outlook.fr>
- Update to release SDK-1.3.275.0
  * New extensions: VK_ARM_scheduling_controls,
    VK_NV_cuda_kernel_launch, VK_IMG_relaxed_line_rasterization,
    VK_EXT_layer_settings, VK_ARM_render_pass_striped,
    VK_KHR_calibrated_timestamps, VK_KHR_vertex_attribute_divisor,
    VK_KHR_video_encode_queue, VK_KHR_video_encode_h264,
    VK_KHR_video_encode_h265, VK_KHR_video_maintenance1,
    VK_KHR_maintenance6, VK_NV_per_stage_descriptor_set.
* Fri Oct 27 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.3.268.0
  * New extensions: VK_QCOM_filter_cubic_clamp,
    VK_QCOM_filter_cubic_weights, VK_QCOM_image_processing2,
    VK_QCOM_ycbcr_degamma, VK_NV_descriptor_pool_overallocation,
    VK_MSFT_layered_driver, VK_NV_low_latency2,
    VK_EXT_nested_command_buffer,
    VK_NV_extended_sparse_address_space.
* Tue Aug 22 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.3.261.0
  * New extensions: VK_EXT_dynamic_rendering_unused_attachments,
    VK_EXT_depth_bias_control, VK_KHR_cooperative_matrix,
    VK_EXT_host_image_copy, VK_NV_device_generated_commands_compute,
    VK_AMDX_shader_enqueue, VK_KHR_maintenance5.
* Tue May 30 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.3.250.0
  * New extensions: VK_EXT_attachment_feedback_loop_dynamic_state,
    VK_KHR_ray_tracing_position_fetch
* Wed Apr 19 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.3.247
  * No changelog
* Wed Apr 19 2023 Jonatas Gonçalves <jonatas.sgoncalves@gmail.com>
- Update to release 1.3.246
  * No changelog
* Tue Mar 28 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.3.243.0
  * No changelog
* Sun Jan 29 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.3.239.0
  * No changelog was provided
* Tue Dec 13 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.3.236.0
  * The VK_EXT_descriptor_buffer extension introduces new
    commands for putting shader-accessible descriptors directly
    in memory.
  * Add VkIcdSurfaceImagePipe.
* Mon Oct 24 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.3.231.0
  * No changelog was provided
    (but do take a look in vulkan-loader/vulkan-validationlayers 231)
- Drop 0001-Drop-wayland-client.h-include.patch (merged upstream)
* Mon Aug 22 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.3.224.0
  * (No change since c896e2f)
* Mon Aug 15 2022 Dirk Müller <dmueller@suse.com>
- update to branch snapshot SDK-1.3.224 (c896e2f):
  * Add issues to the apiext:VK_KHR_dynamic_rendering proposal document
    discussing render area granularity (public issue 1899).
  * Clarify external synchronization requirements for
    ename:VK_DESCRIPTOR_BINDING_UPDATE_AFTER_BIND_BIT and
    ename:VK_DESCRIPTOR_BINDING_UPDATE_UNUSED_WHILE_PENDING_BIT
    elink:VkDescriptorBindingFlagBits and flink:vkUpdateDescriptorSets
    (public issue 1713).
  * Add Vulkan 1.0 valid usage statement for *Subgroup* memory scope to
    <<spirvenv-module-validation-standalone, Standalone SPIR-V Validation>>
    (public merge request 1900).
  * Move "`Hit Kind`" valid usage statement from standalone to runtime
    SPIR-V validation statements (public merge request 1903).
  * Use correct feature in
    ename:VK_PIPELINE_ROBUSTNESS_BUFFER_BEHAVIOR_ROBUST_BUFFER_ACCESS_2_EXT
    description (public pull request 1892).
  * GitHub CI: Regenerate and build-test Rust Vulkan bindings (Ash crate)
    (public pull request 1894).
  * Add dependency of apiext:VK_EXT_blend_operation_advanced on
    apiext:VK_KHR_get_physical_device_properties2. (public merge request
    1887).
  * Update xrefs to features so the feature name is used as the link text,
    and marked up consistently. Added a section to the style guide on markup
    of feature xrefs (public issue 1889).
    elink:VK_COLOR_SPACE_PASS_THROUGH_EXT for a linear or non-gamma transfer
    function color space (public merge request 1729).
  * Fix clamp expression for d_{lo} in the
    <<textures-level-of-detail-operation, Level-of-Detail Operation>>
    section (partial fix for public issue 1836).
  * Update <<spirvenv-module-validation-standalone, Standalone SPIR-V
    Validation>> to add explicit valid usage statements for code:Uniform
    objects being read only, and for code:Block decorations (public merge
    request 1879).
  * Add an issue to apiext:VK_KHR_fragment_shader_barycentric for
    interactions with MSAA (public merge request 1881).
  * Fix XML tagging of slink:VkShaderModuleCreateInfo and add an explicit
    valid usage statement so this structure can be validated both as an
    explicit parameter, and as part of the pname:pNext chain of
    slink:VkPipelineShaderStageCreateInfo (public issue 1883, but a broader
    fix in the validation scripts for this case will eventually be
    required).
  * Update pipeline image to move push constants outside of descriptor sets
    (public issue 1867).
  * Correct code:StencilRefLessFrontEXT to code:DepthLess in the early depth
    test portion of the <<fragops, Fragment Operations>> chapter (public
    pull request 1876).
  * Add new driver id ename:VK_DRIVER_ID_MESA_DOZEN (public pull request
    1877).
  * Relax slink:VkRenderPassCreateInfo valid usage statements 02517 and
    02518 to allow ename:VK_SUBPASS_EXTERNAL (public pull request 1878).
  * Add apiext:VK_KHR_maintenance4 relaxed interface valid usage statement
    to the <<spirvenv-module-validation-runtime, Runtime SPIR-V Validation>>
    section (public pull request 1860).
  * Fix field name in slink:VkRenderingAttachmentInfo valid usage statement
    (public pull request 1861).
  * Fix typo in slink:VkFramebufferCreateInfo valid usage statements 04533 /
    04544 (public pull request 1873).
  * Remove duplicate valid usage statement 06060 (public pull request 1874).
  * Rework <<fxvertex-input-address-calculation, Vertex Input Address
    Calculation>> section (public pull request 1869).
  * Split Github CI script into individual jobs to decrease run time (public
    pull request 1870).
  * Clarify meaning of "`private data slot`" for apiext:VK_EXT_private_data
  * Minor markup fix in the <<spirvenv-module-validation-standalone>>
    section (public merge request 1864).
* Tue Jul 12 2022 Jan Engelhardt <jengelh@inai.de>
- Add 0001-Drop-wayland-client.h-include.patch
* Tue Jun 14 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.3.216.0
  * Fix the structextends and constness issues in
    apiext:VK_EXT_subpass_merge_feedback
* Mon Apr 18 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.3.211.0
  * New extension for helping implementations like Mesa's Zink for
    implementing the OpenGL API atop Vulkan.
    (VK_EXT_image_2d_view_of_3d)
* Tue Feb 15 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.3.204.0
  * Dynamic rendering
  * Buffer device address support is now required
  * Finer control over subgroups
  * Added VK_KHR_shader_integer_dot_product
* Sat Nov 20 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.2.198.0
  * No changelog was provided
* Sun Sep  5 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.2.189
  * No changelog was provided
* Mon Jul  5 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.2.182.0
  * New extensions: VK_EXT_provoking_vertex,
    VK_KHR_shader_subgroup_uniform_control_flow,
    VK_EXT_global_priority_query, VK_EXT_acquire_drm_display,
    VK_EXT_physical_device_drm, VK_EXT_multi_draw,
    VK_HUAWEI_subpass_shading, VK_NV_ray_tracing_motion_blur,
    VK_NV_external_memory_rdma.
* Wed May  5 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.2.176.0
  * Added Vulkan video extensions
* Fri Feb 26 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release SDK-1.2.170.0
  * New VK_KHR_synchronization2 extension.
* Wed Feb 10 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.169
  * No changelog provided
* Wed Jan 27 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.166
  * No changelog provided
* Tue Dec 29 2020 Dirk Müller <dmueller@suse.com>
- update to 1.2.165:
  * loader: Properly check for elevated permissions
  * loader: Remove SEEK_END usage
  * Rename LIB_SUFFIX to VULKAN_LIB_SUFFIX
  * build: Update known-good files for 1.2.165 header
* Mon Dec 14 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.162.0 (sdk)
  * Add GGP (Stadia) WSI platform support to vk_icd.h
* Wed Nov 25 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.161
  * No changelog provided
* Mon Oct 19 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.2.158:
  * Update to match Vulkan-Docs 1.2.158
* Mon Sep 28 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.154
  * No changelog provided
* Thu Sep 10 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.2.153:
  * docs update
* Thu Aug 27 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.2.152:
  * Add VI WSI platform support to vk_icd.h
* Tue Aug 18 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.2.151:
  * Fix enum order for backwards compatibility
  * Update vk_icd.h with typedefs and prototypes
  * Add missing ifdef for extern "C"
  * Add a loader features interface
* Sat Aug  1 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.148
  * No changelog provided
* Sun Jun 28 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to release 1.2.145
  * No changelog provided
* Thu May 28 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.141
  * No changelog provided
* Mon Apr 13 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.137
  * No changelog provided
* Wed Apr  1 2020 Aaron Stern <ukbeast89@protonmail.com>
- Update to release 1.2.135
  * No changelog supplied
* Tue Feb 18 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to release 1.2.133
  * No changelog supplied
* Mon Feb  3 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to release 1.2.132
  * No changelog supplied
* Sun Jan 19 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.131
  * No changelog supplied
* Thu Dec 12 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.1.130
  * The new VK_EXT_tooling_info extension can be used to let the
    Vulkan application/game/engine query what development tools
    are running right now.
* Thu Nov  7 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.1.127
  * VK_KHR_separate_depth_stencil_layouts allows for image memory
    barriers for depth/stencil images to have just one of the
    depth or stencil bits set instead of both.
* Sat Oct 26 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.1.126
  * No changelog supplied
* Wed Oct 16 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.1.124
  * headers: add metal surface support to ICD header
* Sun Sep 22 2019 Aaron Stern <ukbeast89@protonmail.com>
- Update to new upstream release 1.1.123
  * Update headers in accordance with 1.1.123 specification.
* Wed Aug 21 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.1.120
  * Update headers in accordance with 1.1.120 specification.
* Sun Aug 18 2019 Aaron Stern <ukbeast89@ptotonmail.com>
- Update to new upstream release 1.1.119
  * No changelog was provided
* Fri Jun 28 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.1.112
  * No changelog was provided
* Tue Jun  4 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.1.108
  * headers: device creation callbacks for layers
* Sat Mar 16 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.1.102
  * No changelog was provided
* Mon Feb 18 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.1.100
  * Add missing return statement to to_string functions
* Thu Jan 24 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.1.98
  * Header file updated to the 1.1.98 specification
* Tue Dec 18 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.1.96
  * No changelog was provided
* Mon Dec  3 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.1.95
  * New extensions: VK_KHR_shader_float16_int8,
    VK_KHR_shader_float_controls
* Mon Nov 12 2018 Jan Engelhardt <jengelh@inai.de>
- Split vulkan SRPM -> vulkan-headers SRPM, following an upstream
  repository split.
- Update to new upstream release 1.1.91
  * Generally no summary changelog is given for the header files
    by upstream
